@@ -1,10 +1,10 @@
 shared_examples 'an endpoint with a last page' do
   it 'should not give a link with rel "last"' do
-    expect(links).not_to include('rel="last"')
+    expect(link).not_to include('rel="last"')
   end
 
   it 'should not give a link with rel "next"' do
-    expect(links).not_to include('rel="next"')
+    expect(link).not_to include('rel="next"')
   end
 
   it 'should give a link with rel "first"' do
